---
title: <span class="badge object-type-scalar"></span> Decibel
---
# <span class="badge object-type-scalar"></span> Decibel

Decibel (dB)

## Definition

```python
# Decibel (dB)
Decibel: typing.Literal["dB"] = "dB"
```
